==> certmanager-model-v1beta1-5.11.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1beta1/ACMEChallengeSolverHTTP01IngressObjectMetaFluentImpl.java <==
package io.fabric8.certmanager.api.model.acme.v1beta1;

import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ACMEChallengeSolverHTTP01IngressObjectMetaFluentImpl<A extends io.fabric8.certmanager.api.model.acme.v1beta1.ACMEChallengeSolverHTTP01IngressObjectMetaFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.certmanager.api.model.acme.v1beta1.ACMEChallengeSolverHTTP01IngressObjectMetaFluent<A>{
  public ACMEChallengeSolverHTTP01IngressObjectMetaFluentImpl() {
  }
  public ACMEChallengeSolverHTTP01IngressObjectMetaFluentImpl(io.fabric8.certmanager.api.model.acme.v1beta1.ACMEChallengeSolverHTTP01IngressObjectMeta instance) {
    this.withAnnotations(instance.getAnnotations()); 
    this.withLabels(instance.getLabels()); 
  }
  private java.util.Map<java.lang.String,java.lang.String> annotations;
  private java.util.Map<java.lang.String,java.lang.String> labels;
  public A addToAnnotations(java.lang.String key,java.lang.String value) {
    if(this.annotations == null && key != null && value != null) { this.annotations = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(); }
    if(key != null && value != null) {this.annotations.put(key, value);} return (A)this;
  }
  public A addToAnnotations(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.annotations == null && map != null) { this.annotations = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(); }
    if(map != null) { this.annotations.putAll(map);} return (A)this;
  }
  public A removeFromAnnotations(java.lang.String key) {
    if(this.annotations == null) { return (A) this; }
    if(key != null && this.annotations != null) {this.annotations.remove(key);} return (A)this;
  }
  public A removeFromAnnotations(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.annotations == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.annotations != null){this.annotations.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.String> getAnnotations() {
    return this.annotations;
  }
  public <K,V>A withAnnotations(java.util.Map<java.lang.String,java.lang.String> annotations) {
    if (annotations == null) { this.annotations =  null;} else {this.annotations = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(annotations);} return (A) this;
  }
  public java.lang.Boolean hasAnnotations() {
    return this.annotations != null;
  }
  public A addToLabels(java.lang.String key,java.lang.String value) {
    if(this.labels == null && key != null && value != null) { this.labels = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(); }
    if(key != null && value != null) {this.labels.put(key, value);} return (A)this;
  }
  public A addToLabels(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.labels == null && map != null) { this.labels = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(); }
    if(map != null) { this.labels.putAll(map);} return (A)this;
  }
  public A removeFromLabels(java.lang.String key) {
    if(this.labels == null) { return (A) this; }
    if(key != null && this.labels != null) {this.labels.remove(key);} return (A)this;
  }
  public A removeFromLabels(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.labels == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.labels != null){this.labels.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.String> getLabels() {
    return this.labels;
  }
  public <K,V>A withLabels(java.util.Map<java.lang.String,java.lang.String> labels) {
    if (labels == null) { this.labels =  null;} else {this.labels = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(labels);} return (A) this;
  }
  public java.lang.Boolean hasLabels() {
    return this.labels != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ACMEChallengeSolverHTTP01IngressObjectMetaFluentImpl that = (ACMEChallengeSolverHTTP01IngressObjectMetaFluentImpl) o;
    if (annotations != null ? !annotations.equals(that.annotations) :that.annotations != null) return false;
    if (labels != null ? !labels.equals(that.labels) :that.labels != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(annotations,  labels,  super.hashCode());
  }
  
}

==> certmanager-model-v1beta1-5.12.3-sources.jar: io/fabric8/certmanager/api/model/acme/v1beta1/ACMEChallengeSolverHTTP01IngressObjectMetaFluentImpl.java <==
package io.fabric8.certmanager.api.model.acme.v1beta1;

import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ACMEChallengeSolverHTTP01IngressObjectMetaFluentImpl<A extends io.fabric8.certmanager.api.model.acme.v1beta1.ACMEChallengeSolverHTTP01IngressObjectMetaFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.certmanager.api.model.acme.v1beta1.ACMEChallengeSolverHTTP01IngressObjectMetaFluent<A>{
  public ACMEChallengeSolverHTTP01IngressObjectMetaFluentImpl() {
  }
  public ACMEChallengeSolverHTTP01IngressObjectMetaFluentImpl(io.fabric8.certmanager.api.model.acme.v1beta1.ACMEChallengeSolverHTTP01IngressObjectMeta instance) {
    this.withAnnotations(instance.getAnnotations()); 
    this.withLabels(instance.getLabels()); 
  }
  private java.util.Map<java.lang.String,java.lang.String> annotations;
  private java.util.Map<java.lang.String,java.lang.String> labels;
  public A addToAnnotations(java.lang.String key,java.lang.String value) {
    if(this.annotations == null && key != null && value != null) { this.annotations = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.annotations.put(key, value);} return (A)this;
  }
  public A addToAnnotations(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.annotations == null && map != null) { this.annotations = new java.util.LinkedHashMap(); }
    if(map != null) { this.annotations.putAll(map);} return (A)this;
  }
  public A removeFromAnnotations(java.lang.String key) {
    if(this.annotations == null) { return (A) this; }
    if(key != null && this.annotations != null) {this.annotations.remove(key);} return (A)this;
  }
  public A removeFromAnnotations(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.annotations == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.annotations != null){this.annotations.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.String> getAnnotations() {
    return this.annotations;
  }
  public <K,V>A withAnnotations(java.util.Map<java.lang.String,java.lang.String> annotations) {
    if (annotations == null) { this.annotations =  null;} else {this.annotations = new java.util.LinkedHashMap(annotations);} return (A) this;
  }
  public java.lang.Boolean hasAnnotations() {
    return this.annotations != null;
  }
  public A addToLabels(java.lang.String key,java.lang.String value) {
    if(this.labels == null && key != null && value != null) { this.labels = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.labels.put(key, value);} return (A)this;
  }
  public A addToLabels(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.labels == null && map != null) { this.labels = new java.util.LinkedHashMap(); }
    if(map != null) { this.labels.putAll(map);} return (A)this;
  }
  public A removeFromLabels(java.lang.String key) {
    if(this.labels == null) { return (A) this; }
    if(key != null && this.labels != null) {this.labels.remove(key);} return (A)this;
  }
  public A removeFromLabels(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.labels == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.labels != null){this.labels.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.String> getLabels() {
    return this.labels;
  }
  public <K,V>A withLabels(java.util.Map<java.lang.String,java.lang.String> labels) {
    if (labels == null) { this.labels =  null;} else {this.labels = new java.util.LinkedHashMap(labels);} return (A) this;
  }
  public java.lang.Boolean hasLabels() {
    return this.labels != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ACMEChallengeSolverHTTP01IngressObjectMetaFluentImpl that = (ACMEChallengeSolverHTTP01IngressObjectMetaFluentImpl) o;
    if (annotations != null ? !annotations.equals(that.annotations) :that.annotations != null) return false;
    if (labels != null ? !labels.equals(that.labels) :that.labels != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(annotations,  labels,  super.hashCode());
  }
  
}
